==> haskell-xml-conduit-1.9.1.4-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-2gqpbvmdvgKvMli69maLE
key:                  xml-conduit-1.9.1.4-2gqpbvmdvgKvMli69maLE
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  da95724d5f18014961a275fe655cea6f
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-2gqpbvmdvgKvMli69maLE
depends:
    attoparsec-0.14.4-IQNmPMCm4joYQgQ4QRYaD base-4.17.2.1
    blaze-html-0.9.2.0-AWaFw2Mn1VJABJRaM77GAU
    blaze-markup-0.8.3.0-FUfv9i8tjj47GFJ2anwAkD bytestring-0.11.5.3
    conduit-1.3.6.1-8OSOdkGtcaZ23KS6p4zYxn
    conduit-extra-1.3.6-3QToGI63olcEjuwT7XUZCO containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    resourcet-1.2.6-IR3DRlFbTBCF0v7kVv51R text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.9.1.4-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-4XRX1CjvEWmIrgFUaPhfWP
key:                  xml-conduit-1.9.1.4-4XRX1CjvEWmIrgFUaPhfWP
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  922b904d8f84cf281891a7e0ee3d3234
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-4XRX1CjvEWmIrgFUaPhfWP
depends:
    attoparsec-0.14.4-CiUWnNTnUzcEcRmqqSBimu base-4.17.2.1
    blaze-html-0.9.2.0-7rraM1lSLOl2LrVAS4qxq6
    blaze-markup-0.8.3.0-EXIdF6gaJs7HROOmQDdLmZ bytestring-0.11.5.3
    conduit-1.3.6.1-GhV2KMoemFPB5FDryFR5X5
    conduit-extra-1.3.6-4VZQrDv9KU68F339d2BW5y containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    resourcet-1.2.6-1qaZdHoBp5u2zlBnaE55JI text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
